@rem IBM Cognos 8 Special Edition - IBM Cognos 8 Configuration Script C8SE_config_C8.bat
@rem Copyright (C) 2008 Cognos ULC, an IBM Company. All rights reserved. 
@rem Cognos (R) is a trademark of Cognos ULC, (formerly Cognos Incorporated).

@echo off

set C8SE_scripts=%~dp0%

@rem Call the general environment setup script to set env vars
if EXIST "%C8SE_scripts%C8SE_env.bat" (
  call "%C8SE_scripts%C8SE_env.bat"
) else (
  @echo Unable to load %C8SE_scripts%C8SE_env.bat
)

@rem Call the master environment setup script to set env vars
if EXIST "%C8SE_scripts%C8SE_master_env.bat" (
  call "%C8SE_scripts%C8SE_master_env.bat"
) else (
  @echo Unable to load %C8SE_scripts%C8SE_master_env.bat
)

@rem Set the log file name
if NOT DEFINED C8SE_logfile (
  set C8SE_logfile=%C8SE_scripts%C8SE_install.log
)

@rem Set the C8 Version if it is not already set
if NOT DEFINED C8SE_C8_Version (
  set C8SE_C8_Version=C8
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting C8 version>>"%C8SE_logfile%"
)

@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Running IBM Cognos 8 configuration script (%0)>>"%C8SE_logfile%"

@rem Set the C8 directory if it is not already set
if NOT DEFINED C8SE_C8_Dst (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting C8 destination directory>>"%C8SE_logfile%"
  cd ..
  set C8SE_C8_Dst=%CD%
  cd /d %C8SE_scripts%
)

if EXIST "%C8SE_scripts%\C8SE_config_%C8SE_C8_Version%.flg" (
  @echo %DATE% %TIME% WARN: %C8SE_C8_Version%: IBM Cognos 8 configuration is being skipped>>"%C8SE_logfile%"
  goto exit
)

@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: IBM Cognos 8 will be configured in %C8SE_C8_Dst%>>"%C8SE_logfile%"

@rem Locate and set JAVA_HOME
@rem Use the IBM WAS version if available
if EXIST "%C8SE_WAS_Dst%\bin\setupCmdLine.bat" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Calling setupCmdLine from the WAS install to set JAVA_HOME>>"%C8SE_logfile%"
  call "%C8SE_WAS_Dst%\bin\setupCmdLine.bat"
)
if NOT DEFINED JAVA_HOME (
  @rem Check to see if the IBM Cognos 8 directory has a JRE version that can be used as a fall back
  if EXIST "%C8SE_C8_Dst%%C8SE_C8_JRE%" (
    @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting JAVA_HOME to the IBM Cognos 8 shipped version>>"%C8SE_logfile%"
    set JAVA_HOME="%C8SE_C8_Dst%%C8SE_C8_JRE%"
  )
)
@rem check to see if a JAVA_HOME was found and set
if NOT DEFINED JAVA_HOME (
  @echo %DATE% %TIME% FATAL: %C8SE_C8_Version%: Unable to locate a suitable Java Runtime>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_C8_Version%: Unable to locate a suitable Java Runtime
  goto exit 
)
@rem Check to ensure the java binary is actually there
if EXIST "%JAVA_HOME%\bin\java.exe" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Found %JAVA_HOME%\bin\java.exe>>"%C8SE_logfile%"
  set _JAVACMD="%JAVA_HOME%\bin\java.exe"
) else (
  if EXIST "%JAVA_HOME%\jre\bin\java.exe" (
    @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Found %JAVA_HOME%\jre\bin\java.exe>>"%C8SE_logfile%"
    set _JAVACMD="%JAVA_HOME%\jre\bin\java.exe"
  ) else (
    @echo %DATE% %TIME% FATAL: %C8SE_C8_Version%: Unable to locate a suitable Java Runtime executable>>"%C8SE_logfile%"
    @echo FATAL: %C8SE_C8_Version%: Unable to locate a suitable Java Runtime executable
    goto exit 
  )
)
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Using Java Runtime found in %JAVA_HOME%>>"%C8SE_logfile%"

@rem Ensure the Bouncey Castle Security Provider is in place under JAVA_HOME - cannot run config without it
if NOT EXIST "%JAVA_HOME%\jre\lib\ext\%C8SE_C8_SecProv%" (
  if NOT EXIST "%JAVA_HOME%\lib\ext\%C8SE_C8_SecProv%" (
    @echo %DATE% %TIME% FATAL: %C8SE_C8_Version%: Unable to locate "%JAVA_HOME%\jre\lib\ext\%C8SE_C8_SecProv%">>"%C8SE_logfile%"
    @echo FATAL: %C8SE_C8_Version%: Unable to locate "%JAVA_HOME%\jre\lib\ext\%C8SE_C8_SecProv%"
    goto exit 
  )
)

@rem *************************************************
@rem * IBM Cognos 8 Configuration File Modifications *
@rem *************************************************

@rem Ensure the cogstartup.xml file is available for modification
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
  @echo %DATE% %TIME% FATAL: %C8SE_C8_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_C8_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located
  goto exit 
)
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml will be modified>>"%C8SE_logfile%"

@rem Backup the existing configuration file if a backup does not already exist
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Backing up file %C8SE_C8_Dst%\configuration\cogstartup.xml>>"%C8SE_logfile%"
  if EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
    copy /y "%C8SE_C8_Dst%\configuration\cogstartup.xml" "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" >>"%C8SE_logfile%" 2>>&1
  )
)
@rem Verify the backup file is in place
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" (
  @echo %DATE% %TIME% FATAL: %C8SE_C8_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml.backup could not be created>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_C8_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml.backup could not be created
  goto exit 
)

@rem Set variables for all transforms to use
set _JAVACMD=%JAVA_HOME%\bin\java
set _CLASSPATH="%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\jdxslt.jar";"%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\xercesImpl.jar";"%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\xml-apis.jar"
set SOURCEXML="%C8SE_C8_Dst%\configuration\cogstartup.xml"
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Transform prep - _JAVACMD %_JAVACMD%>>"%C8SE_logfile%"
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Transform prep - _CLASSPATH %_CLASSPATH%>>"%C8SE_logfile%"
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Transform prep - SOURCEXML %SOURCEXML%>>"%C8SE_logfile%"

@rem Copy the xslt template to the working file
if EXIST "%C8SE_scripts%C8SE_template_%C8SE_C8_Version%.xslt" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Copying template to xslt file>>"%C8SE_logfile%"
  copy /y "%C8SE_scripts%C8SE_template_%C8SE_C8_Version%.xslt" "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" >>"%C8SE_logfile%" 2>>&1
)
if NOT EXIST "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" (
  @echo %DATE% %TIME% FATAL: %C8SE_C8_Version%: File "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" could not be created>>"%C8SE_logfile%"
  goto exit
)

@rem Check for URI Values and replace in xslt file
if DEFINED C8SE_C8_GW (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting Gateway URI to %C8SE_C8_GW%>>"%C8SE_logfile%"
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" "C8SE_C8_GW" "%C8SE_C8_GW%"
)

if DEFINED C8SE_C8_DISP (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting Dispatcher URI to %C8SE_C8_DISP%>>"%C8SE_logfile%"
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" "C8SE_C8_DISP" "%C8SE_C8_DISP%"
)

if DEFINED C8SE_C8_CM (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting Content Manager URI to %C8SE_C8_CM%>>"%C8SE_logfile%"
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" "C8SE_C8_CM" "%C8SE_C8_CM%"
)

@rem Run the transform
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Applying transformation template against cogstartup.xml>>"%C8SE_logfile%"
"%_JAVACMD%" -cp  %_CLASSPATH% jd.xml.xslt.Stylesheet -OUT "%C8SE_C8_Dst%\configuration\cogstartup_tmp.xml" %SOURCEXML% "%C8SE_scripts%C8SE_config_%C8SE_C8_Version%.xslt" >>"%C8SE_logfile%" 2>>&1
if EXIST %C8SE_C8_Dst%\configuration\cogstartup_tmp.xml (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Copying temporary file to cogstartup.xml>>"%C8SE_logfile%"
  copy /y "%C8SE_C8_Dst%\configuration\cogstartup_tmp.xml" "%C8SE_C8_Dst%\configuration\cogstartup.xml" >>"%C8SE_logfile%" 2>>&1
)
if EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Deleting temporary file>>"%C8SE_logfile%"
  del /q "%C8SE_C8_Dst%\configuration\cogstartup_tmp.xml" >>"%C8SE_logfile%" 2>>&1
)

@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Changing directories to %C8SE_C8_Dst%\bin for IBM Cognos Configuration>>"%C8SE_logfile%"
cd /d "%C8SE_C8_Dst%\bin"
if EXIST cogconfigw.exe (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Running IBM Cognos Configuration in silent mode>>"%C8SE_logfile%"
  cogconfigw -s >>"%C8SE_logfile%" 2>>&1
)
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Changing directories to %C8SE_scripts%>>"%C8SE_logfile%"
cd /d %C8SE_scripts%

@rem Consolidate IBM Cognos log files
if EXIST "%C8SE_C8_Dst%\logs\cogconfig_response.csv" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Append IBM Cognos Configuration silent mode log to C8SE log>>"%C8SE_logfile%"
  type "%C8SE_C8_Dst%\logs\cogconfig_response.csv" >>"%C8SE_logfile%"
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Delete %C8SE_C8_Dst%\logs\cogconfig_response.csv after consolidation>>"%C8SE_logfile%"
  del /q "%C8SE_C8_Dst%\logs\cogconfig_response.csv" >>"%C8SE_logfile%" 2>>&1
)

if NOT EXIST "%C8SE_scripts%\C8SE_config_%C8SE_C8_Version%.flg" (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Creating flag on successful configuration >>"%C8SE_logfile%"
  @echo %DATE% %TIME% %C8SE_C8_Version% >"%C8SE_scripts%\C8SE_config_%C8SE_C8_Version%.flg"
)

:exit
@rem Clear environment variables prior to exiting
@rem 

@rem Return to original location
@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Changing directories to %C8SE_scripts%>>"%C8SE_logfile%"
cd /d %C8SE_scripts%

@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Exiting IBM Cognos 8 configuration script>>"%C8SE_logfile%"

@rem *****************
@rem * End of Script *
@rem *****************